@@ -1096,8 +1096,10 @@ class FormatDecisionState(object):
             self.stack[-1].indent) <= self.column_limit
 
 
-_COMPOUND_STMTS = frozenset(
-    {'for', 'while', 'if', 'elif', 'with', 'except', 'def', 'class'})
+_COMPOUND_STMTS = frozenset({
+    'for', 'while', 'if', 'elif', 'with', 'except', 'def', 'class', 'match',
+    'case'
+})
 
 
 def _IsCompoundStatement(token):
